@@ -26,19 +26,22 @@ class GLib(Tarball, Meson):
         Project.__init__(
             self,
             "glib",
-            archive_url="https://download.gnome.org/sources/glib/2.72/glib-2.72.4.tar.xz",
-            hash="8848aba518ba2f4217d144307a1d6cb9afcc92b54e5c13ac1f8c4d4608e96f0e",
-            dependencies=["ninja", "meson", "pkg-config", "gettext", "libffi", "zlib"],
-            patches=[
-                "glib-package-installation-directory.patch",
-                "0002-pcre-add-fallback-url.patch",
-                "0001-Fix-global-and-local-variables-hidden-by-local-varia.patch",
+            archive_url="https://download.gnome.org/sources/glib/2.74/glib-2.74.1.tar.xz",
+            hash="0ab981618d1db47845e56417b0d7c123f81a3427b2b9c93f5a46ff5bbb964964",
+            dependencies=[
+                "ninja",
+                "meson",
+                "pkg-config",
+                "gettext",
+                "libffi",
+                "zlib",
+                "pcre2",
             ],
         )
 
     def build(self):
         Meson.build(self)
-        self.install(r".\COPYING share\doc\glib")
+        self.install(r".\LICENSES\* share\doc\glib")
 
 
 @project_add
@@ -47,13 +50,9 @@ class GLibNetworking(Tarball, Meson):
         Project.__init__(
             self,
             "glib-networking",
-            archive_url="https://download.gnome.org/sources/glib-networking/2.74/glib-networking-2.72.2.tar.xz",
-            hash="cd2a084c7bb91d78e849fb55d40e472f6d8f6862cddc9f12c39149359ba18268",
+            archive_url="https://download.gnome.org/sources/glib-networking/2.74/glib-networking-2.74.0.tar.xz",
+            hash="1f185aaef094123f8e25d8fa55661b3fd71020163a0174adb35a37685cda613b",
             dependencies=["pkg-config", "ninja", "meson", "glib", "openssl"],
-            patches=[
-                "0001-Mark-strings-for-translation-and-translate-just-in-e.patch",
-                "0002-tlslog-add-meson-config-setting-to-log-at-debug-leve.patch",
-            ],
         )
 
     def build(self):
