@@ -29,7 +29,7 @@ class Libepoxy(Tarball, Meson):
             archive_url="https://github.com/anholt/libepoxy/archive/refs/tags/1.5.10.tar.gz",
             hash="a7ced37f4102b745ac86d6a70a9da399cc139ff168ba6b8002b4d8d43c900c15",
             archive_filename="libepoxy-1.5.10.tar.gz",
-            dependencies=["python", "ninja", "meson"],
+            dependencies=["ninja", "meson"],
         )
 
     def build(self):
